@@ -5,10 +5,10 @@ import math
 import sys
 
 
-class Sequence:
-    def __init__(self, func, dtype):
+class Subscription:
+    def __init__(self, func, iter_type):
         self._func = func
-        self._dtype = dtype
+        self._type = iter_type
 
     def __getitem__(self, key):
         if isinstance(key, int):
@@ -31,10 +31,22 @@ class Sequence:
             else:
                 iterable = map(self._func, itertools.count(key.start, key.step))
                 iterator = itertools.islice(iterable, math.ceil((key.stop - key.start) / key.step))
-            return self._dtype(iterator) if self._dtype else iterator
+            return self._type(iterator) if self._type is not None else iterator
 
 
-def subscriptable(dtype=None, /):
+def subscriptable(iter_type=None, /):
+    """
+    A decorator that transforms a function into a subscription object.
+
+    :param iter_type:
+        The type of data structure returned from the function when ``isinstance(key, slice)``,
+        the default is ``itertools.islice``.
+    :return:
+        The returned value depends on the ``key``,
+        for ``isinstance(key, int)`` no change will be made and
+        for ``isinstance(key, slice)`` the values will be wrapped by ``iter_type``,
+        otherwise ``None`` will be returned.
+    """
     def wrapper(func):
-        return Sequence(func, dtype)
+        return Subscription(func, iter_type)
     return wrapper
